@@ -30,37 +30,42 @@
 #include "buffer.h"
 
 enum {
-    RTTY_FILE_MSG_START_DOWNLOAD,
+    RTTY_FILE_MSG_SEND,
+    RTTY_FILE_MSG_RECV,
     RTTY_FILE_MSG_INFO,
     RTTY_FILE_MSG_DATA,
-    RTTY_FILE_MSG_DATA_ACK,
-    RTTY_FILE_MSG_CANCELED,
+    RTTY_FILE_MSG_ACK,
+    RTTY_FILE_MSG_ABORT,
     RTTY_FILE_MSG_BUSY,
     RTTY_FILE_MSG_PROGRESS,
     RTTY_FILE_MSG_REQUEST_ACCEPT,
     RTTY_FILE_MSG_NO_SPACE,
+    RTTY_FILE_MSG_ERR_EXIST,
     RTTY_FILE_MSG_ERR
 };
 
+#define UPLOAD_FILE_BUF_SIZE (1024 * 16)
+
 struct file_control_msg {
     int type;
     uint8_t buf[128];
 };
 
 struct file_context {
-    int sid;
     int fd;
     bool busy;
     int ctlfd;
     uid_t uid;
     gid_t gid;
+    char sid[33];
+    uint8_t *buf;
     uint32_t total_size;
     uint32_t remain_size;
 };
 
 void request_transfer_file(char type, const char *path);
 
-bool detect_file_operation(uint8_t *buf, int len, int sid, struct file_context *ctx);
+bool detect_file_operation(uint8_t *buf, int len, const char *sid, struct file_context *ctx);
 
 void parse_file_msg(struct file_context *ctx, struct buffer *data, int len);
 
