@@ -411,7 +411,7 @@ static void ssl_verify_cert(void *ssl, void (*on_verify_error)(int error, const
         on_verify_error(r, msg, arg);
 }
 
-int ssl_connect(void *ssl, bool server,
+static int ssl_handshake(void *ssl, bool server,
         void (*on_verify_error)(int error, const char *str, void *arg), void *arg)
 {
     int r;
@@ -432,6 +432,16 @@ int ssl_connect(void *ssl, bool server,
     return SSL_ERROR;
 }
 
+int ssl_accept(void *ssl, void (*on_verify_error)(int error, const char *str, void *arg), void *arg)
+{
+    return ssl_handshake(ssl, true, on_verify_error, arg);
+}
+
+int ssl_connect(void *ssl, void (*on_verify_error)(int error, const char *str, void *arg), void *arg)
+{
+    return ssl_handshake(ssl, false, on_verify_error, arg);
+}
+
 int ssl_write(void *ssl, const void *buf, int len)
 {
     int done = 0;
